@@ -1,7 +1,7 @@
 #
 # This file is part of SVN-Simple-Hook
 #
-# This software is copyright (c) 2011 by GSI Commerce.
+# This software is copyright (c) 2012 by GSI Commerce.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -11,16 +11,16 @@ use strict;
 use Modern::Perl;
 
 package SVN::Simple::Path_Change;
-
-BEGIN {
-    $SVN::Simple::Path_Change::VERSION = '0.301';
+{
+    $SVN::Simple::Path_Change::VERSION = '0.302';
 }
 
 # ABSTRACT: A class for easier manipulation of Subversion path changes
 
 use English '-no_match_vars';
 use Any::Moose;
-use Any::Moose 'X::Types::Path::Class' => [qw(Dir File)];
+use Any::Moose 'X::Types::' . any_moose() => ['Maybe'];
+use Any::Moose 'X::Types::Path::Class'    => [qw(Dir File)];
 use SVN::Core;
 use SVN::Fs;
 use namespace::autoclean;
@@ -38,8 +38,9 @@ has svn_change => (
 );
 
 has path => (
-    is       => 'ro',
-    isa      => Dir | File,    ## no critic (Bangs::ProhibitBitwiseOperators)
+    is => 'ro',
+    ## no critic (Bangs::ProhibitBitwiseOperators)
+    isa => Maybe [ Dir | File ],
     required => 1,
     coerce   => 1,
 );
@@ -49,7 +50,7 @@ has path => (
 =pod
 
 =for :stopwords Mark Gardner GSI Commerce cpan testmatrix url annocpan anno bugtracker rt
-cpants kwalitee diff irc mailto metadata placeholders
+cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =encoding utf8
 
@@ -59,7 +60,7 @@ SVN::Simple::Path_Change - A class for easier manipulation of Subversion path ch
 
 =head1 VERSION
 
-version 0.301
+version 0.302
 
 =head1 SYNOPSIS
 
@@ -93,7 +94,7 @@ returned from the C<< $root->paths_changed() >> method.
 
 =head2 path
 
-Either a L<Path::Class::Dir|Path::Class::Dir> or
+Undefined, or a L<Path::Class::Dir|Path::Class::Dir> or
 L<Path::Class::File|Path::Class::File> representing the changed entity.
 
 =head1 METHODS
@@ -129,7 +130,7 @@ L<http://search.cpan.org/dist/SVN-Simple-Hook>
 
 AnnoCPAN
 
-The AnnoCPAN is a website that allows community annonations of Perl module documentation.
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/SVN-Simple-Hook>
 
@@ -161,7 +162,7 @@ L<http://www.cpantesters.org/distro/S/SVN-Simple-Hook>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
 
 L<http://matrix.cpantesters.org/?dist=SVN-Simple-Hook>
 
@@ -197,7 +198,7 @@ Mark Gardner <mjgardner@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by GSI Commerce.
+This software is copyright (c) 2012 by GSI Commerce.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
